#Set up####
cat("\014")
rm(list=ls())


library(dplyr)
library(tidyverse)
#install.packages("Hmisc")
library(Hmisc)

source('x.axis.year.month_181202_0952.R')

#read in raw WQX data
data0 <- read.csv("../1_Input/Broot_Master_Data_Spreadsheet_2024-11-22_1100_bw.csv")

#Cleaning Data####

#remove quality control rows
data1 <- data0 %>% filter(ActivityTypeCode == 'Field Msr/Obs' | 
                            ActivityTypeCode == 'Sample-Routine')


#get rid of unnecessary columns 
data2 <- data1 %>% select('ActivityTypeCode','ActivityStartDate',
                          'MonitoringLocationIdentifier',
                          'NEWMonitoringLocationName','MethodSpeciationName',
                          'CharacteristicName','ResultConverted',
                          'UnitsConverted')


#changing ActivityStartDate from chars to dates and added to new column StartDate
data2$StartDate <- as.POSIXct(x = data2$ActivityStartDate, tz = "", format = c('%m/%d/%Y'))


#only keep rows with nutrients and flow data using square bracketing
unique(data2$CharacteristicName)

data <- data2[data2$CharacteristicName %in% c('Nitrate + Nitrite', 
                                              'Total Phosphorus, mixed forms',
                                              'Total Nitrogen, mixed forms',
                                              'Flow'),]

unique(data$CharacteristicName)

#Unit conversions####

#converting all results in ug/L to mg/L
# data$Result <- data$ResultConverted
# data[data$ResultMeasure.MeasureUnitCode == 'ug/L',
#      'Result'] <- data[data$ResultMeasure.MeasureUnitCode == 'ug/L', 
#                        'ResultMeasureValue']/1000


#Replacing unit text
# data$Unit <- data$ResultMeasure.MeasureUnitCode
# data$Unit[data$Unit == 'ug/L'] <- 'mg/L'

unique(data$UnitsConverted)

colnames(data) <- c('ActivityTypeCode', 'Date', 'SiteID', 'Site', 'MethodSpeciationName', 
                    'Analyte','Result', 'Unit', 'StartDate')

#Merging nutrients with flow####

#unique(data$Site)

#Creating data frame with only nutrients

nutrients <- data %>% filter(Analyte == 'Nitrate + Nitrite'|
                               Analyte == 'Total Nitrogen, mixed forms'|
                               Analyte == 'Total Phosphorus, mixed forms')

unique(nutrients$Analyte)

#creating data frame with only flow
flow <- data %>% filter(Analyte == 'Flow')


#Only including necessary columns for flow to avoid duplicating columns 
flow <- flow %>% select('StartDate', 'Result', 'Site')


#changing 'Result' column name to flow to avoid confusion in final spreadsheet
colnames(flow) <- c('StartDate', 'Flow', 'Site')


#merging nutrients and flows by date and site
nutrients_flow <- merge(nutrients, flow, by.x=c('StartDate','Site'), 
                        by.y=c('StartDate','Site'))

#Load calculations####

#calculate load
nutrients_flow$Load <- nutrients_flow$Result * nutrients_flow$Flow * 2.45

#Exporting csv####

#output csv file
write.csv(nutrients_flow, "../3_Output/AllNutrientLoads.csv", row.names = FALSE)


#Plotting function for upstream vs downstream loads####

myxlim <- as.POSIXct(c('2021-01-07','2023-12-31'))

load_plot <- function(upstream, downstream, analyte, title, dates){
  
  #create new data frame with only sites and analyte of interest
  sites_plot <- nutrients_flow %>% filter(Site == upstream|
                                            Site == downstream)
  sites_plot <- sites_plot %>% filter(Analyte == analyte)
  
  #add a column with plotting colors for each site
  sites_plot$col[sites_plot$Site == upstream] <- 'sky blue'
  sites_plot$col[sites_plot$Site == downstream] <- 'orange'
  
  #make a scatterplot and save it as a png file
  png(850,400, filename= paste0('../3_Output/Plots/',title,'.png'))
  plot(x = sites_plot$StartDate, y = sites_plot$Load,
       cex = 2.5,
       pch = 16,
       xlab = '',
       xaxt = 'n',
       xlim = myxlim,
       ylab = 'Load (kg/day)',
       cex.lab = 1.5,
       cex.main = 1.5,
       main = title,
       col = sites_plot$col,
       frame.plot = FALSE)
  abline(v=as.POSIXct(c(dates)), lty=2)
  # x.axis.year.month(Xrange = range(sites_plot$StartDate), 
  #                   months.labeled = 1:12,
  #                   axis.line = 0, 
  #                   month.line = 0)
  x.axis.year.month(Xrange = myxlim, 
                    months.labeled = 1:12,
                    axis.line = 0, 
                    month.line = 0,
                    month.cex = 0.8)
  legend('topleft', legend=c(upstream, downstream),  
         fill = c('sky blue',"orange"), bg = "white")
  minor.tick(nx=0, ny=3, tick.ratio=0.5)
  dev.off()
  
  write.csv(sites_plot, paste0('../3_Output/',title,'.csv'), row.names = FALSE)
}

unique(nutrients_flow$Site)
unique(nutrients_flow$Analyte)

# FYI: look at console for list of sites with loads; copy and paste into function below


#Threemile####
load_plot(upstream = 'Threemile Creek C', 
          downstream = 'Threemile Creek A', 
          analyte = 'Total Phosphorus, mixed forms',
          title = 'Total Phosphorus Loads on Threemile Creek', 
          dates = c('2021-09-16','2022-09-21', '2022-10-21','2023-09-29'))

load_plot(upstream = 'Threemile Creek C', 
          downstream = 'Threemile Creek A', 
          analyte = 'Nitrate + Nitrite',
          title = 'Nitrate + Nitrite Loads on Threemile Creek', 
          dates = c('2021-09-16','2022-09-21', '2022-10-21','2023-09-29'))

load_plot(upstream = 'Threemile Creek C', 
          downstream = 'Threemile Creek A', 
          analyte = 'Total Nitrogen, mixed forms',
          title = 'Total Nitrogen Loads on Threemile Creek', 
          dates = c('2021-09-16','2022-09-21', '2022-10-21','2023-09-29'))

#Rye Creek####
load_plot(upstream = 'Rye Creek B', 
          downstream = 'Rye Creek AA', 
          analyte = 'Total Phosphorus, mixed forms',
          title = 'Total Phosphorus Loads on Rye Creek', 
          dates = c('2022-05-30','2022-07-22','2023-10-27'))

load_plot(upstream = 'Rye Creek B', 
          downstream = 'Rye Creek AA',
          analyte = 'Nitrate + Nitrite',
          title = 'Nitrate + Nitrite Loads on Rye Creek', 
          dates = c('2022-05-30','2022-07-22','2023-10-27'))

load_plot(upstream = 'Rye Creek B', 
          downstream = 'Rye Creek AA',
          analyte = 'Total Nitrogen, mixed forms',
          title = 'Total Nitrogen Loads on Rye Creek', 
          dates = c('2022-05-30','2022-07-22','2023-10-27'))

#Skalkaho####
load_plot(upstream = 'Skalkaho Creek C', 
          downstream = 'Skalkaho Creek A', 
          analyte = 'Total Phosphorus, mixed forms',
          title = 'Total Phosphorus Loads on Skalkaho Creek', 
          dates = c('2022-09-20', '2022-10-28'))

load_plot(upstream = 'Skalkaho Creek C', 
          downstream = 'Skalkaho Creek A', 
          analyte = 'Nitrate + Nitrite',
          title = 'Nitrate + Nitrite Loads on Skalkaho Creek', 
          dates = c('2022-09-20', '2022-10-28'))

load_plot(upstream = 'Skalkaho Creek C', 
          downstream = 'Skalkaho Creek A', 
          analyte = 'Total Nitrogen, mixed forms',
          title = 'Total Nitrogen Loads on Skalkaho Creek', 
          dates = c('2022-09-20', '2022-10-28'))

#Willow####
load_plot(upstream = 'Willow Creek B', 
          downstream = 'Willow Creek AA',
          analyte = 'Total Phosphorus, mixed forms',
          title = 'Total Phosphorus Loads on Willow Creek', 
          dates = c('2021-10-10', 
                    '2022-08-18', 
                    '2022-09-12',
                    '2022-10-27',
                    '2023-08-01',
                    '2023-09-04',
                    '2023-09-27',
                    '2023-11-04'))

load_plot(upstream = 'Willow Creek B', 
          downstream = 'Willow Creek AA',
          analyte = 'Nitrate + Nitrite',
          title = 'Nitrate + Nitrite Loads on Willow Creek', 
          dates = c('2021-10-10', 
                    '2022-08-18', 
                    '2022-09-12',
                    '2022-10-27',
                    '2023-08-01',
                    '2023-09-04',
                    '2023-09-27',
                    '2023-11-04'))

load_plot(upstream = 'Willow Creek B', 
          downstream = 'Willow Creek AA', 
          analyte = 'Total Nitrogen, mixed forms',
          title = 'Total Nitrogen Loads on Willow Creek', 
          dates = c('2021-10-10', 
                    '2022-08-18', 
                    '2022-09-12',
                    '2022-10-27',
                    '2023-08-01',
                    '2023-09-04',
                    '2023-09-27',
                    '2023-11-04'))

#N Burnt Fork####
load_plot(upstream = 'N. Burnt Fork Creek C', 
          downstream = 'N. Burnt Fork Creek AA', 
          analyte = 'Total Phosphorus, mixed forms',
          title = 'Total Phosphorus Loads on North Burnt Fork Creek', 
          dates = c('2022-07-24','2022-09-23', '2022-10-29'))

load_plot(upstream = 'N. Burnt Fork Creek C', 
          downstream = 'N. Burnt Fork Creek AA', 
          analyte = 'Nitrate + Nitrite',
          title = 'Nitrate + Nitrite Loads on North Burnt Fork Creek', 
          dates = c('2022-07-24', '2022-10-29'))

load_plot(upstream = 'N. Burnt Fork Creek C', 
          downstream = 'N. Burnt Fork Creek AA', 
          analyte = 'Total Nitrogen, mixed forms',
          title = 'Total Nitrogen Loads on North Burnt Fork Creek', 
          dates = c('2022-07-24', '2022-09-23', '2022-10-29'))

# #OLD PLOTTING CODE used to make function
# sites_plot <- nutrients_flow %>% filter(Site == 'Threemile Creek C'|
#                                           Site == 'Threemile Creek A')
# sites_plot <- sites_plot %>% filter(Analyte == 'Total Phosphorus, mixed forms')
# 
# sites_plot$col[sites_plot$Site == 'Threemile Creek C'] <- 'orange'
# sites_plot$col[sites_plot$Site == 'Threemile Creek A'] <- 'sky blue'
# 
# windows()
# plot(x = sites_plot$StartDate, y = sites_plot$Load,
#      cex = 1.5,
#      pch = 16,
#      xlab = '',
#      xaxt = 'n',
#      xlim = range(sites_plot$StartDate),
#      ylab = 'Load (kg/day)',
#      main = 'Total Phosphorus Loads on Threemile Creek',
#      col = sites_plot$col,
#     frame.plot = FALSE)
# legend("topleft", legend=c('Threemile Creek C', 'Threemile Creek A'),
#        fill = c('orange',"sky blue"), bg = "white")
# x.axis.year.month(Xrange = range(sites_plot$StartDate), months.labeled = 1:12,axis.line = 0, month.line = 0)
# #x.axis.year.month(Xrange = ymd(c('2021-09-16', '2023-11-07')))
# abline(v=as.POSIXct(c('2021-09-16','2022-09-21', '2022-10-21','2023-09-29')))
# 
# range(sites_plot$StartDate)
# 
